===============================
Mapping SQL Expressions
===============================

This page has been merged into the
:ref:`mapper_config_toplevel` index.


.. toctree::
    :hidden:

    mapping_columns

